@@ -1,4 +1,4 @@
-API_KEY = "api_key"
+API_KEY <- "api_key"
 
 #' Set API key
 #'
