@@ -5,18 +5,23 @@
 #' @keywords internal
 #' @noRd
 #' @return A string representation of POSIXct.
-time_format <- function(time, to_utc = FALSE) {
-  time <- anytime(time)
-
-  if (to_utc) {
-    time <- with_tz(time, tzone = "UTC")
-    tz = "GMT"
+time_format <- function(time, to_utc = TRUE) {
+  # nocov start
+  if (is.null(time)) {
+    NULL
   } else {
-    tz = ""
-  }
+    time <- anytime(time)
 
-  strftime(time, "%Y-%m-%dT%H:%M:%OS3Z", tz = tz)
-}
+    if (to_utc) {
+      time <- with_tz(time, tzone = "UTC")
+      tz <- "GMT"
+    } else {
+      tz <- ""
+    }
+
+    strftime(time, "%Y-%m-%dT%H:%M:%OS3Z", tz = tz)
+  }
+} # nocov end
 
 #' Parse times returned by API
 #'
@@ -28,7 +33,10 @@ time_format <- function(time, to_utc = FALSE) {
 #' @keywords internal
 #' @noRd
 #' @return A POSIXct object.
-time_parse <- function(time, format = "%Y-%m-%dT%H:%M:%SZ", to_local = TRUE) {
+time_parse <- function(time,
+                       format = "%Y-%m-%dT%H:%M:%SZ",
+                       to_local = TRUE) {
+  # nocov start
   time <- as.POSIXct(time, format = format, tz = "UTC")
 
   if (to_local) {
@@ -36,4 +44,4 @@ time_parse <- function(time, format = "%Y-%m-%dT%H:%M:%SZ", to_local = TRUE) {
   } else {
     time
   }
-}
+} # nocov end
