@@ -1,3 +1,15 @@
+unpack_workspace <- function(workspace) {
+  workspace$imageUrl <- NULL
+  workspace$featureSubscriptionType <- NULL
+  workspace$workspaceSettings <- NULL
+  workspace$hourlyRate <- NULL
+
+  workspace$memberships <- list(simplify_membership(workspace$memberships))
+
+  as_tibble(workspace) %>%
+    rename(workspace_id = id)
+}
+
 #' Get a list of workspaces
 #'
 #' @return A data frame with one record per workspace.
@@ -12,15 +24,7 @@
 workspaces <- function() {
   GET("/workspaces") %>%
     content() %>%
-    map_df(function(workspace) {
-      with(
-        workspace,
-        tibble(
-          workspace_id = id,
-          name
-        )
-      )
-    })
+    map_df(unpack_workspace)
 }
 
 #' Get or set active workspace ID
@@ -32,8 +36,9 @@ workspaces <- function() {
 #'
 #' @examples
 #' \dontrun{
-#' set_api_key(Sys.getenv("CLOCKIFY_API_KEY"))
-#'
+#' # Select default workspace for authenticated user.
+#' workspace()
+#' # Select a specific workspace.
 #' workspace("612b15a5f4c3bf0462192677")
 #' }
 workspace <- function(workspace_id = NULL) {
